@@ -1,4 +1,4 @@
-package urpm::bug_report; # $Id: bug_report.pm 250871 2009-01-06 17:21:05Z pixel $
+package urpm::bug_report;
 
 use strict;
 use urpm;
@@ -71,7 +71,6 @@ sub copy_requested {
 
 1;
 
-__END__
 
 =back
 
@@ -81,4 +80,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
