@@ -1,12 +1,12 @@
 package urpm::parallel_ssh;
 
-# $Id: parallel_ssh.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 #- Copyright (C) 2002, 2003, 2004, 2005 MandrakeSoft SA
 #- Copyright (C) 2005-2010 Mandriva SA
+#- Copyright (C) 2011-2020 Mageia
 
 use strict;
-use urpm::util;
+use urpm::util 'dirname';
 use urpm::msg;
 use urpm::parallel;
 
