@@ -1,6 +1,5 @@
 package urpm::select;
 
-# $Id: select.pm 258637 2009-07-28 13:14:16Z cfergeau $
 
 use strict;
 use urpm::msg;
@@ -8,7 +7,7 @@ use urpm::util qw(any formatList intersection member min partition uniq);
 use urpm::sys;
 use URPM;
 
-my $default_priority_list = 'rpm,perl-URPM,perl-MDV-Distribconf,urpmi,meta-task,glibc,aria2';
+my $default_priority_list = 'rpm,perl-base,perl-URPM,perl-MDV-Distribconf,urpmi,meta-task,glibc,aria2';
 my @priority_list = split(',', $default_priority_list);
 
 my $evr_re = qr/[^\-]*-[^\-]*\.[^\.\-]*$/;
@@ -308,7 +307,7 @@ installed or upgraded
 
 =item * nodeps
 
-=item * no_suggests
+=item * no_recommends
 
 =back
 
@@ -719,17 +718,20 @@ sub translate_why_removed_one {
 }
 
 sub _libdb_version { $_[0] =~ /libdb-(\S+)\.so/ ? version->new("v$1") : () }
-sub _rpm_version() { `rpm --version` =~ /version ([0-9.]+)(?:-(beta|rc).*)?$/ ? version->new("v$1") : () }
+sub _rpm_version() {
+    local $ENV{LC_ALL} = 'C';
+    `rpm --version` =~ /version ([0-9.]+)(?:-(beta|rc).*)?$/ ? version->new("v$1") : ();
+}
 
 sub should_we_migrate_back_rpmdb_db_version {
     my ($urpm, $state) = @_;
 
-    my ($pkg) = urpm::select::selected_packages_providing($urpm, $state, 'rpm') or return;
-    urpm::select::was_pkg_name_installed($state->{rejected}, 'rpm') and return;
-    my ($rooted_librpm_version) = map { _libdb_version($_) } $pkg->requires; # perl_checker: $self = revision
+    my ($pkg) = selected_packages_providing($urpm, $state, 'rpm') or return;
+    was_pkg_name_installed($state->{rejected}, 'rpm') and return;
+    my ($rooted_libbdb_version) = map { _libdb_version($_) } $pkg->requires; # perl_checker: $self = revision
     my $rooted_rpm_version = version->new("v" . $pkg->version); # perl_checker: $self = revision
 
-    my $urpmi_librpm_version = _libdb_version(scalar `ldd /bin/rpm`); # perl_checker: $self = revision
+    my $urpmi_libbdb_version = _libdb_version(scalar `ldd /bin/rpm`); # perl_checker: $self = revision
 
     if (_rpm_version() ge v4.9.0) { # perl_checker: $self = revision
 	if ($rooted_rpm_version && $rooted_rpm_version ge v4.9) {
@@ -738,8 +740,8 @@ sub should_we_migrate_back_rpmdb_db_version {
 	    $urpm->{need_migrate_rpmdb} = '4.8';
 	    return 1;
 	}
-    } elsif ($urpmi_librpm_version ge v4.6) {
-	if ($rooted_librpm_version && $rooted_librpm_version ge v4.6) {
+    } elsif ($urpmi_libbdb_version ge v4.6) {
+	if ($rooted_libbdb_version && $rooted_libbdb_version ge v4.6) {
 	    $urpm->{debug} and $urpm->{debug}("chrooted db version used by librpm is at least as good as non-rooted one");
 	} else {
 	    foreach my $bin ('db_dump', 'db42_load') {
@@ -754,6 +756,27 @@ sub should_we_migrate_back_rpmdb_db_version {
     0;
 }
 
+sub migrate_forward_rpmdb_db_if_needed {
+    my ($urpm) = @_;
+
+    my ($pkg) = $urpm->packages_providing('rpm') or return;
+    my $rooted_rpm_version = version->new("v" . $pkg->version); # perl_checker: $self = revision
+    my $rpm_version = _rpm_version(); # perl_checker: $self = revision
+
+    if ($rpm_version ge v4.16.0) {
+	if ($rooted_rpm_version && $rooted_rpm_version ge v4.16) {
+	    $urpm->{debug} and $urpm->{debug}("chrooted db version used by librpm is at least as good as non-rooted one");
+	    if (-f "$urpm->{root}/var/lib/rpm/Packages") {
+		$urpm->{debug} and $urpm->{debug}("Migrating chrooted db");
+		$urpm->{need_migrate_rpmdb_now} = '4.16';
+		urpm::sys::migrate_forward_rpmdb_db_version($urpm);
+		return 1;
+	    }
+	}
+    }
+    0;
+}
+
 1;
 
 =back
