@@ -1,6 +1,5 @@
 package urpm::util;
 
-# $Id: util.pm 271299 2010-11-21 15:54:30Z peroyvind $
 
 use strict;
 use Exporter;
@@ -29,8 +28,8 @@ our @EXPORT = qw(add2hash_
     put_in_hash
     quotespace
     reduce_pathname
-    remove_internal_name
     same_size_and_mtime
+    uefi_type
     uniq
     uniq_
     unquotespace
@@ -38,13 +37,38 @@ our @EXPORT = qw(add2hash_
     wc_l
 );
 
+
+=head1 NAME
+
+urpm::util - Misc. utilities subs for urpmi
+
+Mostly a subset of L<MDK::Common>
+
+See C<perldoc MDK::Common> for more documentation
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+=head1 FUNCTIONS
+
+=over
+
+=cut
+
 sub min  { my $n = shift; $_ < $n and $n = $_ foreach @_; $n }
 sub max  { my $n = shift; $_ > $n and $n = $_ foreach @_; $n }
 
-#- quoting/unquoting a string that may be containing space chars.
+=item quotespace($str)
+
+=item unquotespace($str)
+
+Quoting/unquoting a string that may be containing space chars.
+
+=cut
+
 sub quotespace		 { my $x = $_[0] || ''; $x =~ s/(\s)/\\$1/g; $x }
 sub unquotespace	 { my $x = $_[0] || ''; $x =~ s/\\(\s)/$1/g; $x }
-sub remove_internal_name { my $x = $_[0] || ''; $x =~ s/\(\S+\)$/$1/g; $x }
 
 sub dirname { local $_ = shift; s|[^/]*/*\s*$||; s|(.)/*$|$1|; $_ || '.' }
 sub basename { local $_ = shift; s|/*\s*$||; s|.*/||; $_ }
@@ -59,14 +83,19 @@ sub file2absolute_file {
     $f;
 }
 
-#- reduce pathname by removing <something>/.. each time it appears (or . too).
+=item reduce_pathname($url)
+
+Reduce pathname by removing <something>/.. each time it appears (or . too).
+
+=cut
+
 sub reduce_pathname {
     my ($url) = @_;
 
     #- clean url to remove any macro (which cannot be solved now).
     #- take care if this is a true url and not a simple pathname.
     my ($host, $dir) = $url =~ m|([^:/]*://[^/]*/)?(.*)|;
-    $host = '' if !defined $host;
+    $host //= '';
 
     #- remove any multiple /s or trailing /.
     #- then split all components of pathname.
@@ -94,8 +123,13 @@ sub reduce_pathname {
     $host . $dir;
 }
 
-#- offset pathname by returning the right things to add to a relative directory
-#- to make no change. url is needed to resolve going before to top base.
+=item offset_pathname($url, $offset)
+
+Offset pathname by returning the right things to add to a relative directory
+to make no change. url is needed to resolve going before to top base.
+
+=cut
+
 sub offset_pathname {
     my ($url, $offset) = map { reduce_pathname($_) } @_;
 
@@ -136,7 +170,12 @@ sub move {
     rename($file, $dest) || !system("/bin/mv", "-f", $file, $dest);
 }
 
-#- file_size is useful to write file_size(...) > 32 without having warnings if file doesn't exist
+=item file_size($file)
+
+It is useful to write file_size(...) > 32 without having warnings if file doesn't exist
+
+=cut
+
 sub file_size {
     my ($file) = @_;
     -s $file || 0;
@@ -187,7 +226,20 @@ sub uniq_(&@) {
 
 sub output_safe {
     my ($file, $content, $o_backup_ext) = @_;
-    
+
+    #- The file must be world-readable, else mgaapplet and urpm* commands run as
+    #- a normal user won't be able to read it. We enforce umask here in the case
+    #- where the msec security level is set to 'secure' (which means umask 077)
+    #- or where we are run from a gdm-x-session (mga#24636)
+    my $old_umask = umask 0022;
+    my $retval = output_safe_($file, $content, $o_backup_ext);
+    umask $old_umask;
+    $retval;
+}
+
+sub output_safe_ {
+    my ($file, $content, $o_backup_ext) = @_;
+
     open(my $f, '>', "$file.new") or return;
     print $f $content or return;
     close $f or return;
@@ -216,19 +268,25 @@ sub append_to_file {
     1;
 }
 
+=item uefi_type()
+
+Return the UEFI machine type short name
+
+=cut
+
+# FIXME: move into urpm::sys ?
+sub uefi_type() {
+    if (-e '/sys/firmware/efi/fw_platform_size') {
+        # No support for ARM yet
+        cat_('/sys/firmware/efi/fw_platform_size') =~ /32/ ? 'ia32' : 'x64';
+    } else {
+        'none';
+    }
+}
+
 1;
 
-__END__
-
-=head1 NAME
-
-urpm::util - Misc. utilities subs for urpmi
-
-Mostly a subset of L<MDK::Common>
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
+=back
 
 =head1 COPYRIGHT
 
@@ -236,4 +294,6 @@ Copyright (C) 2005 MandrakeSoft SA
 
 Copyright (C) 2005-2010 Mandriva SA
 
+Copyright (C) 2011-2020 Mageia
+
 =cut
